@@ -1,10 +1,4 @@
-"""
-nodes.py
---------
-
-Nodes that make up the Manuscript tree.
-
-"""
+"""Nodes that make up the Manuscript tree."""
 
 from typing import Any, Type, Optional, Callable, ClassVar, TypeVar, cast, Union
 from collections.abc import Iterable
@@ -24,6 +18,8 @@ class RSMNodeError(Exception):
 
 
 class Node:
+    """Base Node class."""
+
     classreftext: ClassVar[str] = "{nodeclass} {number}"
     possible_parents: ClassVar[set[Type["NodeWithChildren"]]] = set()
     autonumber: ClassVar[bool] = False
